@@ -38,7 +38,6 @@ mesh_mode_flag = 0
 
 mesh_config_ack = False
 
-
 __onebot_login = _mesh_login_class()
 __aiqi_adapter = aiqi_bluetooth.Aiqi_Bluetooth_Class()
 
@@ -286,15 +285,19 @@ __wait_char_stats = False
 __print_char = ""
 __print_char_num = 0
 __print_char_num_max = 0
-def __print_wait_char(time=0.1,maxnum=10):
-    global __print_char,__print_char_num,__wait_char_stats
+
+
+def __print_wait_char(time=0.1, maxnum=10):
+    global __print_char, __print_char_num, __wait_char_stats
     __print_char_num_max = maxnum
     if __wait_char_stats:
-        __print_char +='█'
-        print("\r"+__print_char+"  "+str(__print_char_num)+"/"+str(int(maxnum)), end='')
-        threading.Timer(time, __print_wait_char,args=(time,maxnum)).start()
+        __print_char += '█'
+        print("\r" + __print_char + "  " + str(__print_char_num) + "/" + str(int(maxnum)), end='')
+        threading.Timer(time, __print_wait_char, args=(time, maxnum)).start()
     __print_char_num += 1
-    if __print_char_num > __print_char_num_max and __print_char_num_max != 0:
+    if __print_char_num > __print_char_num_max:
+        __print_char_num = 0
+        __print_char = ""
         __wait_char_stats = False
 
 
@@ -326,12 +329,14 @@ def __user_console_select(devs):
                     print(devs_index)
                     return False
             return True
+
         aiqi_blue_type.Print_Scan_Onebot_Device(user_select_buff)
-        print('Please enter the number of the connected index , multiple sequences separated by spaces,Or directly enter, all the default configuration')
+        print(
+            'Please enter the number of the connected index , multiple sequences separated by spaces,Or directly enter, all the default configuration')
         print('Input sequence, determine the control sequence, please choose according to your needs')
         user_input = input('(Enter or input index):').split()
         if len(user_input) != 0:
-            user_input = list(map(int,user_input))
+            user_input = list(map(int, user_input))
             if checkvalid(user_input):
                 user_new_buff = []
                 for i in user_input:
@@ -348,8 +353,10 @@ def __user_console_select(devs):
 
 
 __App_Reset = ''
+
+
 async def onebot_getdevices_process():
-    global __dev_type, __dev_mac_addr,__wait_char_stats
+    global __dev_type, __dev_mac_addr, __wait_char_stats
 
     global __bluetooth_scan_list, __get_message_done_stats
 
@@ -373,9 +380,9 @@ async def onebot_getdevices_process():
 
         await __aiqi_adapter.scan_ctrl(True)
         __wait_char_stats = True
-        __print_wait_char(0.5,blue_scan_parm.scantimeout/0.5)
+        __print_wait_char(0.5, blue_scan_parm.scantimeout / 0.5)
 
-        await asyncio.sleep(blue_scan_parm.scantimeout+1)
+        await asyncio.sleep(blue_scan_parm.scantimeout + 1)
         await __aiqi_adapter.scan_ctrl(False)
         __wait_char_stats = False
         print('\nscan stop')
@@ -418,13 +425,13 @@ async def __onebot_login_process():
     try:
         print("Please wait for a connection, up to eight seconds......")
         __wait_char_stats = True
-        __print_wait_char(0.5,30)
-        await __aiqi_adapter.connect(__dev_mac_addr,timeout=8)
+        __print_wait_char(1, 8)
+        await __aiqi_adapter.connect(__dev_mac_addr, timeout=8)
 
     except:
         __wait_char_stats = False
         print("\nDevice connection timeout")
-        sys.exit("0")
+        sys.exit()
     __wait_char_stats = False
     print("\n")
 
@@ -447,11 +454,11 @@ async def __onebot_login_process():
         print('shake .....')
 
 
-    elif __dev_type == 5:  # mesh 设备 mesh设备连接后需要根据设备版本号判断是否加密
+    elif __dev_type == 5:  #
         print('Detection version.....', end='')
         await __aiqi_adapter.senddata(mesh_report.get_version)
         time.sleep(0.1)
-        print('version ' + __onebot_login.Get_Version_Str())
+        print(' ' + __onebot_login.Get_Version_Str())
         if __onebot_login.dev_version >= __onebot_login.need_login_version:
             await __aiqi_adapter.senddata(mesh_report.get_sn)
             time.sleep(0.1)
@@ -509,9 +516,9 @@ async def sendDate(data):
         print('ble disconect')
 
 
-
 User_Disconnect_Handle = None
 
+
 def _disconnect_callback(res):
     global ONEBOT_Connect_Stats, onebot_client
     # print('disconnect')
@@ -522,20 +529,20 @@ def _disconnect_callback(res):
         User_Disconnect_Handle(res)
 
 
-
-
-def Aiqi_Bluetooth_Disconnect_CallBack_Register(callback):
-    global User_Disconnect_Handle
-    # print('connect callback reg')
-    User_Disconnect_Handle = callback
+# def Aiqi_Bluetooth_Disconnect_CallBack_Register(callback):
+#     global User_Disconnect_Handle
+#     # print('connect callback reg')
+#     User_Disconnect_Handle = callback
 
 
 ONEBOT_Connect_Stats = False
 
+
 async def app_exit():
     await __aiqi_adapter.disconnect()
     time.sleep(0.1)
 
+
 @atexit.register
 def atexit_fun():
     print('sys exit')
@@ -547,15 +554,17 @@ def atexit_fun():
 app_reset : if is 'new' ,will clear local save all devices
 
 '''
-def start(app_reset='',scantimeout=5,rssi=-100,namelist=[],maclist=[]):
-    global blue_scan_parm,__App_Reset
+
+
+def start(app_reset='', scantimeout=5, rssi=-100, namelist=[], maclist=[],disconnect_callback=None):
+    global blue_scan_parm, __App_Reset,User_Disconnect_Handle
     __App_Reset = app_reset.lower()
     print('start')
     parm = aiqi_blue_type.aiqi_bluetooth_scan_class()
     parm.scantimeout = scantimeout
     parm.scannamelist = namelist[:]
     parm.scanmaclist = maclist[:]
-
+    User_Disconnect_Handle = disconnect_callback
     blue_scan_parm = parm
     loop = asyncio.get_event_loop()
     loop.run_until_complete(onebot_getdevices_process())
